@@ -12,9 +12,11 @@
    Web service app
 ----------------------"""
 
+import flask
 from flask import Flask, Response
 
 from idds.common import exceptions
+from idds.common.authentication import authenticate_x509, authenticate_oidc
 from idds.common.constants import HTTP_STATUS_CODE
 from idds.common.utils import get_rest_debug
 # from idds.common.utils import get_rest_url_prefix
@@ -25,6 +27,8 @@ from idds.rest.v1 import hyperparameteropt
 from idds.rest.v1 import logs
 from idds.rest.v1 import monitor
 from idds.rest.v1 import messages
+from idds.rest.v1 import ping
+from idds.rest.v1 import auth
 
 
 class LoggingMiddleware(object):
@@ -50,7 +54,7 @@ class LoggingMiddleware(object):
         return self._app(environ, log_response)
 
 
-def get_blueprints():
+def get_normal_blueprints():
     bps = []
     bps.append(requests.get_blueprint())
     bps.append(catalog.get_blueprint())
@@ -59,17 +63,63 @@ def get_blueprints():
     bps.append(logs.get_blueprint())
     bps.append(monitor.get_blueprint())
     bps.append(messages.get_blueprint())
+    bps.append(ping.get_blueprint())
+
     return bps
 
 
-def create_app():
+def get_auth_blueprints():
+    bps = []
+    bps.append(auth.get_blueprint())
+    return bps
+
+
+def generate_failed_auth_response(exc_msg=None):
+    resp = Response(response=None, status=HTTP_STATUS_CODE.Unauthorized, content_type='application/json')
+    resp.headers['ExceptionClass'] = exceptions.IDDSException.__name__
+    resp.headers['ExceptionMessage'] = exc_msg
+    return resp
+
+
+def before_request_auth():
+    auth_type = flask.request.headers.get('X-IDDS-Auth-Type', default='x509_proxy')
+    vo = flask.request.headers.get('X-IDDS-Auth-VO', default=None)
+    if auth_type in ['x509_proxy']:
+        dn = flask.request.environ.get('SSL_CLIENT_S_DN', None)
+        client_cert = flask.request.environ.get('SSL_CLIENT_CERT', None)
+        is_authenticated, errors = authenticate_x509(vo, dn, client_cert)
+        if not is_authenticated:
+            return generate_failed_auth_response(errors)
+    elif auth_type in ['oidc']:
+        token = flask.request.headers.get('X-IDDS-Auth-Token', default=None)
+        is_authenticated, errors = authenticate_oidc(vo, token)
+        if not is_authenticated:
+            return generate_failed_auth_response(errors)
+    else:
+        errors = "Authentication method %s is not supported" % auth_type
+        return generate_failed_auth_response(errors)
+
+
+def after_request(response):
+    return response
+
+
+def create_app(auth_type=None):
     # url_prefix = get_rest_url_prefix()
-    bps = get_blueprints()
     application = Flask(__name__)
+
+    bps = get_auth_blueprints()
     for bp in bps:
         # application.register_blueprint(bp, url_prefix=url_prefix)
         application.register_blueprint(bp)
 
+    bps = get_normal_blueprints()
+    for bp in bps:
+        bp.before_request(before_request_auth)
+        bp.after_request(after_request)
+        # application.register_blueprint(bp, url_prefix=url_prefix)
+        application.register_blueprint(bp)
+
     # application.before_request(before_request)
     # application.after_request(after_request)
     if get_rest_debug():
